### Name: tableContinuous
### Title: Generate a LaTeX table of descriptive statistics for continuous
###   variables
### Aliases: tableContinuous
### Keywords: manip character

### ** Examples

set.seed(1977)
vars <- list(c(rnorm(90), NA), rgamma(100, 2, 1))
nams <- c("Var1", "Var2")
group <- sample(c(rep("A", 50), rep("B", 50)))
subset <- c(1:70, 91:100)

## display default statistics
tableContinuous(vars, nams, group, subset, stats = c("n", "min", "q1", "mean", 
    "median", "q3", "max", "iqr", "na"), prec = 1, col.tit = NA, print.pval = 
    "kruskal", cap = "Table of continuous variables.", lab = "tab: descr stat")

## supply user-defined statistics: trimmed mean and IQR as an unbiased estimate 
## of the population standard deviation
my.stats <- list("n", "mean", "$\bar{x}_{trim}$" = function(x){return(mean(x, 
    trim = .05))}, "iqr", "IQR.unbiased" = function(x){return(IQR(x) / 
    (2 * qnorm(3 / 4)))})
tableContinuous(vars, nams, group, subset, stats = my.stats, prec = 1, 
    col.tit = NA, print.pval = "kruskal", cap = "Table of continuous variables.", 
    lab = "tab: descr stat")

## disp.cols can still be used, for backward compatibility
tableContinuous(vars, nams, group, subset, disp.cols = c("n", "min", "median", 
    "max", "iqr", "na"), prec = 1, col.tit = NA, print.pval = "kruskal", 
    cap = "Table of continuous variables.", lab = "tab: descr stat")



